
package Java2OWL;

import TestPackage.Person;
import java.io.File;
import java.util.ArrayList;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;
import org.semanticweb.owlapi.model.IRI;
import org.semanticweb.owlapi.model.OWLOntology;
import org.semanticweb.owlapi.model.OWLOntologyCreationException;
import org.semanticweb.owlapi.model.OWLOntologyStorageException;

/**
 *
 * @author ohlbach
 */
public class J2OWLCompilerTest {
    
    static J2OManager manager;
    static J2OOntologyManager omg;
    static J2OClassManager clm; 
    static J2OCompiler cmp ;
    static Logging logger;
    
    public J2OWLCompilerTest() {
    }

    @BeforeClass
    public static void setUpClass() throws Exception { 
        Class jcla = J2OWLCompilerTest.class;
        manager = new J2OManager("TestManager",J2OManager.Status.COMPILE,true);
        omg = manager.getOntologyManager();
        clm = manager.getClassManager();
        cmp = manager.getCompiler();
        logger = manager.getLogger();
        logger.activate(true);
    }

    @AfterClass
    public static void tearDownClass() throws Exception {
    }
    
    @Before
    public void setUp() {
    }
    
    
    @After
    public void tearDown() {
    }
 
    
     /**
     * Test of parseParameters method, of class J2OWLCompiler.
     */
    
    @Test
    public void testParseParameters() {
        System.out.println("parseParameters");
        String[] args = {"build/test/classes/TestPackage/Person.class", 
                        "build/test/classes/TestPackage/Person$Student.class", 
                         "build/classes/Java2OWL", 
                        "bgo", "test/Java2OWL/BackgroundOntology.owl",
                        "exof", "test/Java2OWL/ExtOntology.owl",
                        "sync", "true"};
        Object[] parameters = Utilities.parseParameters(args, J2OCompiler.postfixes, J2OCompiler.keys);

        parameters = cmp.parseParameters(parameters);
        //System.out.println("PAR " + J2OCompiler.parametersToString(parameters));
        ArrayList<Class> classes = (ArrayList<Class>)(parameters[0]);
        IRI backgroundOntologyIRI = (IRI)(parameters[1]);
        IRI extensionOntologyFileIRI = (IRI)(parameters[2]);
        IRI extensionOntologyIRIIRI = (IRI)(parameters[3]); 
        String reasonerName = (String)(parameters[4]);
        boolean sync = (Boolean)(parameters[5]);
        

        assertEquals(true,classes.size() > 10);
        assertEquals("TestPackage.Person",classes.get(0).getName());
        assertEquals(true,backgroundOntologyIRI.toString().endsWith("BackgroundOntology.owl"));
        assertEquals(true,extensionOntologyFileIRI.toString().endsWith("ExtOntology.owl"));
        assertEquals(true,extensionOntologyIRIIRI.toString().endsWith("BackgroundOntologyExtension.owl"));
        assertEquals(J2OCompiler.defaultReasoner,reasonerName);
        assertEquals(true,sync);
        
        args = new String[]{"bgo", "test/Java2OWL/BackgroundOntology.owl",
                        "exof", "test/Java2OWL/ExtOntology.owl",
                        "exoi", "http://www.lmu.de/ExtOnt.owl",
                        "log", "all", 
                        "reasoner", "FaCT++","sync", "true"};
        parameters = Utilities.parseParameters(args, J2OCompiler.postfixes, J2OCompiler.keys);
        parameters = cmp.parseParameters(parameters);
        //System.out.println("PA " + J2OCompiler.parametersToString(parameters));
       
     }
    
    /**
     * Test of class2OWL method, of class J2OWLCompiler.
     */
    @Test
    public void testClass2OWL_Class() throws OWLOntologyCreationException, OWLOntologyStorageException {
        System.out.println("class2OWL"); 
        String name = "test/Java2OWL/BackgroundOntology.owl";
        OWLOntology bgOntology = omg.loadBackgroundOntology(name);
        IRI iri = IRI.create("http://www.lmu.de/ExtentionOntology2.owl");
        OWLOntology extOntology = omg.createExtensionOntology(true, iri);
        omg.setReasoner("HermiT", true, false, 10000);
        
        Class jcl = Person.class;
        //System.out.println("JCL " + jcl);
        cmp.class2OWL(jcl,new J2OSynchroniser());
        iri = IRI.create(new File("test/Java2OWL/ExtensionOntology2.owl"));
        boolean success = cmp.finishTranslation(iri);
        assertEquals(true,success); 
    }

   /**
     * Test of main method, of class J2OWLCompiler.
     */
    @Test
    public void testMain() throws ClassNotFoundException {
        System.out.println("main");
        String[] args = {"build/test/classes/TestPackage/Person.class", 
                        "bgo", "test/Java2OWL/BackgroundOntology.owl",
                        "exof", "test/Java2OWL/ExtensionOntology2.owl","sync","true","debug","true","log","all"};
        J2OCompiler.main(args);
        // now check ExtensionOntology2.owl with Protege 
        
    }
    
      
}
