/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package Java2OWL;

import java.io.InputStreamReader;
import java.io.FileInputStream;
import java.io.BufferedReader;
import Java2OWL.Logging.Destination;
import Java2OWL.Logging.Origin;
import Java2OWL.Logging.Semantics;
import java.io.IOException;
import java.util.logging.Formatter;
import java.util.logging.Handler;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;

/**
 *
 * @author ohlbach
 */
public class LoggingTest {
    
    public LoggingTest() {
    }

    Logging logger = null;
    
    @BeforeClass
    public static void setUpClass() throws Exception {
    }

    @AfterClass
    public static void tearDownClass() throws Exception {
    }
    
    @Before
    public void setUp() {
        logger = new Logging(null);
        try{logger.setHandler(Destination.BUFFER, "");} catch(Exception ex) {}
    }
    
    @After
    public void tearDown() {
    }

    String readFile(String file) {
        String s = "";
        BufferedReader reader = null;
        try{
            reader = new BufferedReader(new InputStreamReader(new FileInputStream(file)));
            while(reader.ready()) s += reader.readLine()+"\n";}
        catch(Exception ex){ex.printStackTrace();}
        finally{try{reader.close();}catch(Exception ex){}};
        return s;}

    /**
     * Test of getName method, of class Logging.
     */
    @Test
    public void testGetName() {
        System.out.println("getName");
        assertEquals("Logger", logger.getName());
    }

     /**
     * Test of setDebugMode method, of class Logging.
     */
    @Test
    public void testDefault() {
        System.out.println("DefaultMode");
        
        logger.info("INFORMATION");
        assertEquals(true,logger.getContents().matches(".*INFORMATION.*\\s?"));
        logger.clear();
        logger.error("FEHLER",Logging.Origin.UNCLEAR); 
        assertEquals(true,logger.getContents().matches(".*FEHLER.*\\s?"));
        assertEquals(true,logger.hasErrors());
        logger.clear();
        logger.warning("WARNUNG",Logging.Origin.UNCLEAR);
        assertEquals(false,logger.hasErrors());
          
        assertEquals(true,logger.getContents().matches(".*WARNUNG.*\\s?"));
        
        logger.clear();
        logger.entering("ENTERING");
        assertEquals(true,logger.getContents().matches(".*ENTERING.*\\s?"));
        logger.clear();
        logger.entering("EXITING");
        assertEquals(true,logger.getContents().matches(".*EXITING.*\\s?"));
        assertEquals(true,logger.hasContents());
     
        logger.clear();
        logger.correlation(Logging.Semantics.OCC, "A", "B");
        assertEquals(true,logger.getContents().matches(".*Correlation.* A.*B.*\\s?"));
    }
    
    @Test
    public void testErrorsOnly() {
        System.out.println("ErrorsOnly");
        logger.activateInfo(false);
        
        logger.info("INFORMATION");
        assertEquals(false,logger.hasContents());
        assertEquals("",logger.getContents());
        logger.clear();
        logger.error("FEHLER",Logging.Origin.UNCLEAR); 
        assertEquals(true,logger.getContents().matches(".*FEHLER.*\\s?"));
        assertEquals(true,logger.hasErrors());
        logger.clear();
        logger.warning("WARNUNG",Logging.Origin.UNCLEAR);
        assertEquals(false,logger.hasErrors());
        logger.clear();
        logger.entering("ENTERING");
        assertEquals(false,logger.hasContents()); 
        logger.clear();
        logger.entering("EXITING");
        assertEquals(false,logger.hasContents());
    }
    
    @Test
    public void testSelectiveActivation() {
        System.out.println("selectiveActivation");
        logger.activate(Logging.Semantics.OCC,Logging.Semantics.DC);
        
        logger.info("INFORMATION");
        assertEquals(false,logger.hasContents());
        logger.clear();
        logger.entering("ENTERING");
        assertEquals(false,logger.hasContents());
        logger.clear();
        logger.error("FEHLER",Logging.Origin.UNCLEAR); 
        assertEquals(true,logger.getContents().matches(".*FEHLER.*\\s?"));
        logger.clear();
        logger.event(Logging.Semantics.OCC, "CLASS");
        assertEquals(true,logger.getContents().matches(".*CLASS.*\\s?"));
        logger.clear();
        logger.event(Logging.Semantics.DC, "DVC");
        assertEquals(true,logger.getContents().matches(".*DVC.*\\s?"));
        logger.clear();
        logger.event(Logging.Semantics.JOC, "JOC");
        assertEquals(false,logger.hasContents());
    }
    @Test
    public void testFileHandler() throws IOException {
        System.out.println("file handler");
        logger.setHandler(Destination.FILE, "/tmp/J2OLOG");
        logger.info("INFORMATION");
        logger.event(Logging.Semantics.DC, "DVC");
        logger.finalize();
        assertEquals(true,readFile("/tmp/J2OLOG").matches(".*INFORMATION(.|\\s)*"));
        logger.clear();
        logger.info("TEST");
        logger.finalize();
        assertEquals(true,readFile("/tmp/J2OLOG").matches(".*TEST(.|\\s)*"));
    }
    
    @Test
    public void testSystemOut() throws IOException {
        System.out.println("System out");
        logger.setHandler(Destination.OUT, "");
        logger.info("INFORMATION");
        logger.event(Logging.Semantics.DC, "DVC");
        logger.info("TEST");
        logger.flush();
    }
    
}
